@@ -1,33 +1,21 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "templatehandler_test.h"
 
-#include <kateglobal.h>
-#include <katedocument.h>
-#include <kateview.h>
-#include <kateconfig.h>
-#include <katetemplatehandler.h>
 #include <KTextEditor/Cursor>
+#include <kateconfig.h>
+#include <katedocument.h>
+#include <kateglobal.h>
+#include <katetemplatehandler.h>
+#include <kateview.h>
 
-#include <QtTestWidgets>
 #include <QString>
+#include <QtTestWidgets>
 
 QTEST_MAIN(TemplateHandlerTest)
 
@@ -41,33 +29,36 @@ TemplateHandlerTest::TemplateHandlerTest()
 
 void TemplateHandlerTest::testUndo()
 {
-    const QString snippet = "for (${type=\"int\"} ${index=\"i\"} = ; ${index} < ; ++${index})\n"
-                            "{\n"
-                            "    ${index}\n"
-                            "}";
+    const QString snippet =
+        "for (${type=\"int\"} ${index=\"i\"} = ; ${index} < ; ++${index})\n"
+        "{\n"
+        "    ${index}\n"
+        "}";
 
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
 
     // fixed indentation options
     doc->config()->setTabWidth(8);
     doc->config()->setIndentationWidth(4);
     doc->config()->setReplaceTabsDyn(true);
 
-    view->insertTemplate({0, 0}, snippet);
+    view->insertTemplate(KTextEditor::Cursor(0, 0), snippet);
 
-    const QString result = "for (int i = ; i < ; ++i)\n"
-                           "{\n"
-                           "    i\n"
-                           "}";
+    const QString result =
+        "for (int i = ; i < ; ++i)\n"
+        "{\n"
+        "    i\n"
+        "}";
     QCOMPARE(doc->text(), result);
 
     doc->replaceText(Range(0, 9, 0, 10), "j");
 
-    const QString result2 = "for (int j = ; j < ; ++j)\n"
-                            "{\n"
-                            "    j\n"
-                            "}";
+    const QString result2 =
+        "for (int j = ; j < ; ++j)\n"
+        "{\n"
+        "    j\n"
+        "}";
     QCOMPARE(doc->text(), result2);
 
     doc->undo();
@@ -81,10 +72,11 @@ void TemplateHandlerTest::testUndo()
     doc->insertText(Cursor(0, 10), "j");
     doc->insertText(Cursor(0, 11), "j");
 
-    const QString result3 = "for (int jjj = ; jjj < ; ++jjj)\n"
-                            "{\n"
-                            "    jjj\n"
-                            "}";
+    const QString result3 =
+        "for (int jjj = ; jjj < ; ++jjj)\n"
+        "{\n"
+        "    jjj\n"
+        "}";
     QCOMPARE(doc->text(), result3);
 
     doc->undo();
@@ -104,8 +96,8 @@ void TemplateHandlerTest::testUndo()
 
 void TemplateHandlerTest::testEscapes()
 {
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
     view->insertTemplate({0, 0}, QStringLiteral("\\${field} ${bar} \\${foo=3} \\\\${baz=7}"));
     QCOMPARE(doc->text(), QStringLiteral("${field} bar ${foo=3} \\${baz=7}"));
 }
@@ -114,8 +106,8 @@ void TemplateHandlerTest::testSimpleMirror()
 {
     QFETCH(QString, text);
 
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
     view->insertTemplate({0, 0}, text);
 
     QCOMPARE(doc->text(), QString(text).replace("${foo}", "foo"));
@@ -137,10 +129,38 @@ void TemplateHandlerTest::testSimpleMirror_data()
     QTest::newRow("several") << "${foo} ${foo} Foo ${foo}";
 }
 
+void TemplateHandlerTest::testAlignC()
+{
+    QFETCH(QString, input);
+    QFETCH(QString, expected);
+
+    auto doc = new KTextEditor::DocumentPrivate();
+    doc->setHighlightingMode("C");
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
+    view->insertTemplate({0, 0}, input);
+
+    QCOMPARE(doc->text(), expected);
+
+    delete doc;
+}
+
+void TemplateHandlerTest::testAlignC_data()
+{
+    QTest::addColumn<QString>("input");
+    QTest::addColumn<QString>("expected");
+
+    QTest::newRow("one") << "/* ${foo} */"
+                         << "/* foo */";
+    QTest::newRow("simple") << "/**\n* ${foo}\n*/"
+                            << "/**\n * foo\n */";
+    QTest::newRow("complex") << "/**\n* @brief: ${...}\n* \n*/"
+                             << "/**\n * @brief: ...\n * \n */";
+}
+
 void TemplateHandlerTest::testAdjacentRanges()
 {
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
 
     using S = QString;
     view->insertTemplate({0, 0}, S("${foo} ${foo}"));
@@ -162,8 +182,8 @@ void TemplateHandlerTest::testTab()
     QFETCH(QString, tpl);
     QFETCH(int, cursor);
 
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
 
     view->insertTemplate({0, 0}, tpl);
     view->setCursorPosition({0, cursor});
@@ -203,8 +223,8 @@ void TemplateHandlerTest::testTab_data()
 
 void TemplateHandlerTest::testExitAtCursor()
 {
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
 
     view->insertTemplate({0, 0}, QStringLiteral("${foo} ${bar} ${cursor} ${foo}"));
     view->setCursorPosition({0, 0});
@@ -221,7 +241,7 @@ void TemplateHandlerTest::testExitAtCursor()
     QCOMPARE(doc->text(), QStringLiteral("foo bar a foo"));
 
     // required to process the deleteLater() used to exit the template handler
-    QCoreApplication::sendPostedEvents(0, QEvent::DeferredDelete);
+    QCoreApplication::sendPostedEvents(nullptr, QEvent::DeferredDelete);
     QApplication::processEvents();
 
     // go to the first field and verify it's not mirrored any more (i.e. the handler exited)
@@ -234,12 +254,11 @@ void TemplateHandlerTest::testExitAtCursor()
 
 void TemplateHandlerTest::testDefaultMirror()
 {
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
 
     using S = QString;
-    view->insertTemplate({0, 0}, S("${foo=uppercase(\"hi\")} ${bar=3} ${foo}"),
-                             S("function uppercase(x) { return x.toUpperCase(); }"));
+    view->insertTemplate({0, 0}, S("${foo=uppercase(\"hi\")} ${bar=3} ${foo}"), S("function uppercase(x) { return x.toUpperCase(); }"));
     QCOMPARE(doc->text(), S("HI 3 HI"));
     doc->insertText({0, 0}, "xy@");
     QCOMPARE(doc->text(), S("xy@HI 3 xy@HI"));
@@ -249,12 +268,11 @@ void TemplateHandlerTest::testDefaultMirror()
 
 void TemplateHandlerTest::testFunctionMirror()
 {
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
 
     using S = QString;
-    view->insertTemplate({0, 0}, S("${foo} hi ${uppercase(foo)}"),
-                            S("function uppercase(x) { return x.toUpperCase(); }"));
+    view->insertTemplate({0, 0}, S("${foo} hi ${uppercase(foo)}"), S("function uppercase(x) { return x.toUpperCase(); }"));
     QCOMPARE(doc->text(), S("foo hi FOO"));
     doc->insertText({0, 0}, "xy@");
     QCOMPARE(doc->text(), S("xy@foo hi XY@FOO"));
@@ -264,8 +282,8 @@ void TemplateHandlerTest::testFunctionMirror()
 
 void TemplateHandlerTest::testAutoSelection()
 {
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
 
     view->insertTemplate({0, 0}, "${foo} ${bar} ${bar} ${cursor} ${baz}");
     QCOMPARE(doc->text(), QStringLiteral("foo bar bar  baz"));
@@ -297,8 +315,8 @@ void TemplateHandlerTest::testNotEditableFields()
     QFETCH(QString, input);
     QFETCH(int, change_offset);
 
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
     view->insertTemplate({0, 0}, input);
 
     doc->insertText({0, change_offset}, "xxx");
@@ -317,13 +335,11 @@ void TemplateHandlerTest::testNotEditableFields_data()
 
 void TemplateHandlerTest::testCanRetrieveSelection()
 {
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
     view->insertText("hi world");
     view->setSelection(KTextEditor::Range(0, 1, 0, 4));
-    view->insertTemplate({0, 1}, QStringLiteral("xx${foo=sel()}xx"),
-        QStringLiteral("function sel() { return view.selectedText(); }")
-    );
+    view->insertTemplate({0, 1}, QStringLiteral("xx${foo=sel()}xx"), QStringLiteral("function sel() { return view.selectedText(); }"));
     QCOMPARE(doc->text(), QStringLiteral("hxxi wxxorld"));
 }
 
@@ -342,8 +358,7 @@ void TemplateHandlerTest::testDefaults_data()
     QTest::newRow("string_mirror") << S("${foo=\"Bar\"} ${foo}") << S("Bar Bar") << S();
     QTest::newRow("func_simple") << S("${foo=myfunc()}") << S("hi") << S("function myfunc() { return 'hi'; }");
     QTest::newRow("func_fixed") << S("${myfunc()}") << S("hi") << S("function myfunc() { return 'hi'; }");
-    QTest::newRow("func_constant_arg") << S("${foo=uppercase(\"Foo\")}") << S("FOO")
-                                       << S("function uppercase(x) { return x.toUpperCase(); }");
+    QTest::newRow("func_constant_arg") << S("${foo=uppercase(\"Foo\")}") << S("FOO") << S("function uppercase(x) { return x.toUpperCase(); }");
     QTest::newRow("func_constant_arg_mirror") << S("${foo=uppercase(\"hi\")} ${bar=3} ${foo}") << S("HI 3 HI")
                                               << S("function uppercase(x) { return x.toUpperCase(); }");
     QTest::newRow("cursor") << S("${foo} ${cursor}") << S("foo ") << S();
@@ -353,13 +368,13 @@ void TemplateHandlerTest::testDefaults_data()
 
 void TemplateHandlerTest::testDefaults()
 {
-    auto doc = new KTextEditor::DocumentPrivate(false, false, 0, 0);
-    auto view = static_cast<KTextEditor::ViewPrivate*>(doc->createView(nullptr));
+    auto doc = new KTextEditor::DocumentPrivate();
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc->createView(nullptr));
 
     QFETCH(QString, input);
     QFETCH(QString, function);
 
-    view->insertTemplate({0, 0}, input, function);
+    view->insertTemplate(KTextEditor::Cursor(0, 0), input, function);
     QTEST(doc->text(), "expected");
 
     view->selectAll();
